package cc.fascinated.model.user.hmd;

import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * @author Fascinated (fascinated7)
 */
@AllArgsConstructor
@Getter
public enum DeviceHeadset {
    UNKNOWN("Unknown", 0),

    /**
     * Oculus HMDs
     */
    OCULUS_CV1("Rift", 1),
    OCULUS_QUEST("Quest", 32),
    OCULUS_QUEST_2("Quest 2", -1),
    OCULUS_QUEST_3("Quest 3", -1),
    OCULUS_RIFT_S("Rift S", 16),

    /**
     * Windows Mixed Reality HMDs
     * todo: find the new format name
     */
    WINDOWS_MR("Windows Mixed Reality", 8),

    /**
     * HTC HMDs
     */
    HTC_VIVE("Vive", 2),
    HTC_VIVE_COSMOS("Vive Cosmos", 128),

    /**
     * HP HMDs
     */
    HP_REVERB("HP Reverb", -1),

    /**
     * Valve HMDs
     */
    VALVE_INDEX("Valve Index", 64);

    /**
     * The name of the headset.
     */
    private final String name;

    /**
     * The fallback value of the headset.
     */
    private final int fallbackValue;

    /**
     * Gets a headset by its name.
     *
     * @param name the name of the headset
     * @return the headset
     */
    public static DeviceHeadset getByName(String name) {
        for (DeviceHeadset deviceHeadset : values()) {
            if (deviceHeadset.getName().equalsIgnoreCase(name)) {
                return deviceHeadset;
            }
        }
        return null;
    }

    /**
     * Gets a headset by its fallback value.
     *
     * @param fallbackValue the fallback value of the headset
     * @return the headset
     */
    public static DeviceHeadset getByFallbackValue(int fallbackValue) {
        for (DeviceHeadset deviceHeadset : values()) {
            if (deviceHeadset.getFallbackValue() == fallbackValue) {
                return deviceHeadset;
            }
        }
        return null;
    }
}
